import sys,os
def girdi(nedenilcek = ">>"):
    return input(nedenilcek)
def crosscls():
    if sys.platform.startswith("win"):
        os.system("cls")
    else:
        os.system("clear")
def baslik(yazi):
    print(fr"----- {yazi} -----")
def ehe(): # öylesine, eğlence için
    print("ehe")
def satirbasi():
    print("\r")
def renkmodunuac():
    os.system('')
def bossatir(sayi: 1):
    for i in range(sayi):
        print()



import math
temp = ""
temp1 = ""
temp2 = ""

def mutlak(sayi = int):
    global temp
    temp = sayi
    temp = str(temp)
    temp = temp.replace("-","")
    return temp
def topla(sayi,sayie): return sayi + sayie
def cikart(sayi,sayie): return sayi - sayie
def carp(sayi,sayie): return sayi * sayie
def bol(sayi,sayie):
    global temp1
    try:
        temp1 = sayi / sayie
    except ZeroDivisionError:
        return None
    return temp1 # 1 kere bölüyoruz optimizasyon
def negatif(sayi): return 0 - sayi
def kendiylecarp(sayi): return sayi * sayi
def kendiyletopla(sayi): return sayi + sayi
def pi(): return "3.1415926535897932384626433832795028841971693993751058209749445923078164062862089986280348253421170679"
def sin(sayi):
    global temp2
    try:
        temp2 = math.sin(sayi)
    except:
        return None
    return temp2
def sayiyayakin(sayi: int):
    return sayi - 0.00001
def sonsuzluksimge(): return "∞"
print("\033[31mWarning: NOT THREAD-SAFE. GLOBAL VARIABLES ARE USED FOR SIMPLICITY. DO NOT USE IN WEB SERVERS. \nUyarı: THREAD-SAFE DEĞİLDİR. BASİTLİK İÇİN GLOBAL DEĞİŞKENLER KULLANILMIŞTIR. WEB SUNUCULARINDA KULLANMAYIN.\033[0m",flush=True)



import os; os.system('')
from typing import Tuple
RENKSIFIRLA   = "\033[0m"
KALIN     = "\033[1m"
SOLUK = "\033[2m"
ITALIK    = "\033[3m"
ALTCIZGILI = "\033[4m"
YANIPSONEN = "\033[5m"
SIYAH          = "\033[30m"
KIRMIZI        = "\033[31m"
YESIL          = "\033[32m"
SARI           = "\033[33m"
MAVI           = "\033[34m"
MOR            = "\033[35m"
CAMGOBEGI      = "\033[36m"
BEYAZ          = "\033[37m"
PARLAK_SIYAH   = "\033[90m"
PARLAK_KIRMIZI = "\033[91m"
PARLAK_YESIL   = "\033[92m"
PARLAK_SARI    = "\033[93m"
PARLAK_MAVI    = "\033[94m"
PARLAK_MOR     = "\033[95m"
PARLAK_CAMGOBEGI = "\033[96m"
PARLAK_BEYAZ   = "\033[97m"
def renkliyazdir(renk,yazi):
    print(renk,yazi,RENKSIFIRLA)
def truecolorcode(rgb: Tuple[int, int, int]) -> str:
    """
    Bir RGB üçlüsünden (255, 105, 180) True Color ANSI kodunu oluşturur.
    """
    r, g, b = rgb
    # \033[38;2;<R>;<G>;<B>m formatı.
    return f"\033[38;2;{r};{g};{b}m"
